AdminLTE 3 | Modals & Alerts

# Modals & Alerts new

### Modal Examples

Instructions for how to use modals are available on the Bootstrap documentation

### Toasts Examples built in AdminLTE

### SweetAlert2 Examples

For more examples look at https://sweetalert2.github.io/

### Toastr Examples

For more examples look at https://codeseven.github.io/toastr/

#### Default Modal

One fine body…

#### Default Modal

One fine body…

#### Primary Modal

One fine body…

#### Secondary Modal

One fine body…

#### Info Modal

One fine body…

#### Warning Modal

One fine body…

#### Success Modal

One fine body…

#### Danger Modal

One fine body…

#### Small Modal

One fine body…

#### Large Modal

One fine body…

#### Extra Large Modal

One fine body…